@@ -1,3 +1,26 @@
+/**
+ * The MIT License (MIT)
+ *
+ * Copyright (c) 2016-2021 Intel Corporation
+ *
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in all
+ * copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+ * SOFTWARE.
+ */
 package com.intel.gkl.pairhmm;
 
 import org.apache.logging.log4j.LogManager;
@@ -82,15 +105,15 @@ public class IntelPairHmm implements PairHMMNativeBinding {
             int availThreads = gklUtils.getAvailableOmpThreads();
             int maxThreads = Math.min(reqThreads, availThreads);
 
-            logger.info("Available threads: " + availThreads);
-            logger.info("Requested threads: " + reqThreads);
+            logger.info(String.format("Available threads: %d", availThreads));
+            logger.info(String.format("Requested threads: %d", reqThreads));
             if (reqThreads > availThreads) {
-                logger.warn("Using " + maxThreads + " available threads, but " + reqThreads + " were requested");
+                logger.warn(String.format("Using %d available threads, but %d were requested", maxThreads, reqThreads));
             }
         }
         else {
             if (reqThreads != 1) {
-                logger.warn("Ignoring request for " + reqThreads + " threads; not using OpenMP implementation");
+                logger.warn(String.format("Ignoring request for %d threads; not using OpenMP implementation", reqThreads));
             }
         }
     }
@@ -106,9 +129,21 @@ public class IntelPairHmm implements PairHMMNativeBinding {
     @Override
     public void computeLikelihoods(ReadDataHolder[] readDataArray,
                                    HaplotypeDataHolder[] haplotypeDataArray,
-                                   double[] likelihoodArray)
+                                   double[] likelihoodArray) throws NullPointerException, OutOfMemoryError, IllegalArgumentException
     {
-        computeLikelihoodsNative(readDataArray, haplotypeDataArray, likelihoodArray);
+        if(readDataArray == null || haplotypeDataArray == null || likelihoodArray == null) {
+            throw new NullPointerException("Input is null");
+        }
+        try {
+            computeLikelihoodsNative(readDataArray, haplotypeDataArray, likelihoodArray);
+        } catch (OutOfMemoryError e) {
+            logger.warn("Exception thrown from native PairHMM computeLikelihoodsNative function call %s", e.getMessage());
+            throw new OutOfMemoryError("Memory allocation failed");
+        } catch (IllegalArgumentException e) {
+            logger.warn("Exception thrown from native PairHMM computeLikelihoodsNative function call %s", e.getMessage());
+            throw new IllegalArgumentException("Ran into invalid argument issue");
+        }
+
     }
 
     /**
